/*--------------------------------------------------------------------------
W4051A.H
Header file for the Atmel 89C4041 - WakeUp
 2005 Ales Vobornik
--------------------------------------------------------------------------*/

/*  BYTE Registers  */
sfr SP      = 0x81;     // Stack Pointer
sfr DPL     = 0x82;     // Data Pointer Low
sfr DPH     = 0x83;     // Data Pointer High
sfr PCON    = 0x87;     // Power Control
sfr TCON    = 0x88;     // Timer Control
sfr TMOD    = 0x89;     // Timer Mode Control
sfr TL0     = 0x8A;     // Timer 0 Low
sfr TL1     = 0x8B;     // Timer 1 Low
sfr TH0     = 0x8C;     // Timer 0 High
sfr TH1     = 0x8D;     // Timer 1 High

sfr P1      = 0x90;     // Port 1
sfr SCON    = 0x98;     // Serial Port Control
sfr SBUF    = 0x99;     // Serial Port Buffer

sfr IE      = 0xA8;     // Interrupt Enable

sfr P3      = 0xB0;     // Port 3
sfr IP      = 0xB8;     // Interrupt Priority

sfr PSW     = 0xD0;     // Program Status Word

sfr ACC     = 0xE0;     // Accumulator

sfr B       = 0xF0;     // B Register

/*  BIT Registers  */
/*  PCON (0x87) Bit Values  */
#define IDL_    0x01    // Idle Mode Bit: 1=Active
#define STOP_   0x02    // Stop Mode Bit: 1=Active

#define GF0_    0x04    // General Purpose Flag 0
#define GF1_    0x08    // General Purpose Flag 1

#define SMOD_   0x80    // Double Baud Rate

/*  TCON (0x88) Bit Registers  */
sbit IT0  = 0x88;       // Interrupt 0 Type Control
sbit IE0  = 0x89;       // Interrupt 0 Edge Flag
sbit IT1  = 0x8A;       // Interrupt 1 Type Control
sbit IE1  = 0x8B;       // Interrupt 1 Edge Flag
sbit TR0  = 0x8C;       // Timer 0 Run Control
sbit TF0  = 0x8D;       // Timer 0 Overflow Flag
sbit TR1  = 0x8E;       // Timer 1 Run Control
sbit TF1  = 0x8F;       // Timer 1 Overflow Flag

/*  TMOD (0x89) Bit Values  */
#define T0_M0_   0x01   // Timer 0 Mode Bit 0
#define T0_M1_   0x02   // Timer 0 Mode Bit 1
#define T0_CT_   0x04   // Timer 0 Counter/Timer Select: 0=Timer, 1=Counter
#define T0_GATE_ 0x08   // Timer 0 Gate Control

#define T1_M0_   0x10   // Timer 1 Mode Bit 0
#define T1_M1_   0x20   // Timer 1 Mode Bit 1
#define T1_CT_   0x40   // Timer 1 Counter/Timer Select: 0=Timer, 1=Counter
#define T1_GATE_ 0x80   // Timer 1 Gate Control

#define T1_MASK_ 0xF0   // Timer 0 Mask
#define T0_MASK_ 0x0F   // Timer 1 Mask

/*  P1 (0x90) Bit Registers  */
sbit CLK  = 0x95;
sbit IO   = 0x96;
sbit RST  = 0x97; 

/*  SCON (0x98) Bit Registers  */
sbit RI   = 0x98;       // Receive Interrupt Flag
sbit TI   = 0x99;       // Transmit Interrupt Flag
sbit RB8  = 0x9A;       // 9th data bit received
sbit TB8  = 0x9B;       // 9th data bit to be transmitted
sbit REN  = 0x9C;       // Receive Enable
sbit SM2  = 0x9D;       // Serial Port Mode Bit 2
sbit SM1  = 0x9E;       // Serial Port Mode Bit 1
sbit SM0  = 0x9F;       // Serial Port Mode Bit 0

/*  IE (0xA8) Bit Registers  */
sbit EX0  = 0xA8;       // External Interrupt 0 Enable: 1=Enabled
sbit ET0  = 0xA9;       // Timer 0 Interrupt Enable: 1=Enabled
sbit EX1  = 0xAA;       // External Interrupt 1 Enable: 1=Enabled
sbit ET1  = 0xAB;       // Timer 1 Interrupt Enable: 1=Enabled
sbit ES   = 0xAC;       // UART 0 Interrupt Enable: 1=Enabled

sbit EA   = 0xAF;       // Global Interrupt Enable: 0=Disable all interrupts

/*  P3 (0xB0) Bit Registers  */
sbit SLEEP= 0xB2;
sbit ON   = 0xB3;

/*  IP (0xB8) Bit Registers (Least Significant)  */
sbit PX0  = 0xB8;       // External Interrupt 0 Priority
sbit PT0  = 0xB9;       // Timer 0 Interrupt Priority
sbit PX1  = 0xBA;       // External Interrupt 1 Priority
sbit PT1  = 0xBB;       // Timer 1 Interrupt Priority
sbit PS   = 0xBC;       // Serial Port 0 Interrupt Priority

/*  PSW (0xD0) Bit Registers  */
sbit P    = 0xD0;       // Parity Flag
sbit FL   = 0xD1;       // User Flag
sbit OV   = 0xD2;       // Overflow Flag
sbit RS0  = 0xD3;       // Register Bank Select Bit 0
sbit RS1  = 0xD4;       // Register Bank Select Bit 1
sbit F0   = 0xD5;       // User Flag 0
sbit AC   = 0xD6;       // Auxiliary Carry Flag
sbit CY   = 0xD7;       // Carry Flag

/*  Interrupt Vectors  */
#define IE0_VECTOR   0  // 0x03 External Interrupt 0
#define VECTOR_TIMER 1  // 0x1B Timer 0
#define IE1_VECTOR   2  // 0x13 External Interrupt 1
#define TF1_VECTOR   3  // 0x0B Timer 1
#define VECTOR_S     4  // 0x23 Serial port
